==> mysql-8.0.26.tar.gz: mysql-8.0.26/storage/ndb/src/common/debugger/signaldata/IndxAttrInfo.cpp <==
/*
   Copyright (c) 2003, 2021, Oracle and/or its affiliates.
    Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include <signaldata/IndxAttrInfo.hpp>

bool 
printINDXATTRINFO(FILE * output, const Uint32 * theData, Uint32 len, 
                  Uint16 receiverBlockNo)
{
//  const IndxAttrInfo * const sig = (IndxAttrInfo *) theData;

  Uint32 i = 0;
  while (i < len)
    fprintf(output, " H\'%.8x", theData[i++]);
  fprintf(output,"\n");

  return true;
}

==> mysql-8.4_8.4.6.orig.tar.gz: mysql-8.4.6/storage/ndb/src/common/debugger/signaldata/IndxAttrInfo.cpp <==
/*
   Copyright (c) 2003, 2025, Oracle and/or its affiliates.
    Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include <signaldata/IndxAttrInfo.hpp>

bool printINDXATTRINFO(FILE *output, const Uint32 *theData, Uint32 len,
                       Uint16 /*receiverBlockNo*/) {
  //  const IndxAttrInfo * const sig = (const IndxAttrInfo *) theData;

  Uint32 i = 0;
  while (i < len) fprintf(output, " H\'%.8x", theData[i++]);
  fprintf(output, "\n");

  return true;
}
